.. image:: https://img.shields.io/pypi/v/django-otp-notify?color=blue
   :target: https://pypi.org/project/django-otp-notify/
   :alt: PyPI
.. image:: https://img.shields.io/readthedocs/django-otp-notify
   :target: https://django-otp-notify.readthedocs.io/
   :alt: Documentation
.. image:: https://img.shields.io/badge/github-django--otp--notify-green
   :target: https://github.com/django-otp/django-otp-notify
   :alt: Source

This is a django-otp plugin that delivers tokens via Notify's `SMS
<https://www.notifications.service.gov.uk>`_ service.

See `django-otp <https://pypi.org/project/django-otp>`_ for more information
on the OTP framework.

This project is heavily inspired by `django-otp-twilio <https://pypi.org/project/django-otp-twilio/>`_.
